pub struct Breakpoint {
pub column: Option<i64>,
pub end_column: Option<i64>,
pub end_line: Option<i64>,
pub id: Option<i64>,
pub line: Option<i64>,
pub message: Option<String>,
pub source: Option<Source>,
pub verified: bool,
}Expand description
Information about a Breakpoint created in setBreakpoints or setFunctionBreakpoints.
Fields
column: Option<i64>An optional start column of the actual range covered by the breakpoint.
end_column: Option<i64>An optional end column of the actual range covered by the breakpoint. If no end line is given, then the end column is assumed to be in the start line.
end_line: Option<i64>An optional end line of the actual range covered by the breakpoint.
id: Option<i64>An optional identifier for the breakpoint. It is needed if breakpoint events are used to update or remove breakpoints.
line: Option<i64>The start line of the actual range covered by the breakpoint.
message: Option<String>An optional message about the state of the breakpoint. This is shown to the user and can be used to explain why a breakpoint could not be verified.
source: Option<Source>The source where the breakpoint is located.
verified: boolIf true breakpoint could be set (but not necessarily at the desired location).